==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/hr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Group" : "Grupa",
    "Required" : "Obavezan sudionik",
    "Optional" : "Neobavezan sudionik",
    "Does not attend" : "Ne sudjeluje",
    "{name} ({email})" : "{name} ({email})",
    "New event" : "Novi događaj",
    "CalDAV address for clients" : "Adresa CalDAV za klijente",
    "Share Calendar" : "Zajedničko korištenje Kalendara",
    "Shared" : "Resurs podijeljen",
    "WebDAV address for subscriptions" : "Adresa WebDAV za pretplate",
    "group" : "Grupa",
    "Details" : "Detalji",
    "Attendees" : "Sudionici",
    "Reminders" : "Podsjetnici",
    "Repeating" : "Ponavljanje",
    "Confirmed" : "Potvrđeno",
    "Tentative" : "Probno",
    "Cancelled" : "Otkazano",
    "None" : "Ništa",
    "Every day" : "Svakodnevno",
    "never" : "nikad",
    "after" : "nakon",
    "5 minutes before" : "5 minuta prije",
    "10 minutes before" : "10  minuta prije",
    "15 minutes before" : "15  minuta prije",
    "30 minutes before" : "30  minuta prije",
    "1 hour before" : "1 sat prije",
    "2 hours before" : "2 sata prije",
    "Audio" : "Audio",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min",
    "hours" : "sati",
    "days" : "dana",
    "week" : "tjedan",
    "before" : "prije",
    "Title of the Event" : "Naslov Događaja",
    "Delete" : "Izbrišite",
    "Cancel" : "Odustanite",
    "More ..." : "Više...",
    "Create" : "Kreirajte",
    "Update" : "Ažurirajte",
    "Close" : "Zatvorite",
    "Location" : "Lokacija",
    "Description" : "Opis",
    "Visibility when sharing" : "Vidljivost prilikom dijeljenja",
    "Export" : "Izvoz",
    "Day" : "Dan",
    "Week" : "tjedan",
    "Month" : "Mjesec",
    "Today" : "Danas",
    "More" : "Više",
    "Edit" : "Uređivanje",
    "Link" : "Poveznica",
    "iCal link" : "iCal link",
    "Download" : "Preuzmi",
    "Share with users or groups" : "Podijeli s korisnicima ili grupama",
    "can edit" : "uređivanje moguće",
    "Share link" : "Podijeli vezu",
    "Public access" : "Javni pristup",
    "Email link to person" : "Pošalji vezu e-poštom",
    "Send" : "Pošalji",
    "New Calendar" : "Novi kalendar",
    "Name" : "Naziv",
    "New Subscription" : "Nova Pretplata",
    "Go back" : "Nazad",
    "Go forward" : "Dalje",
    "Edit event" : "Uredi događaj",
    "Delete Event" : "Izbriši događaj",
    "Save Event" : "Spremi događaj",
    "Time" : "Vrijeme",
    "Type" : "Vrsta",
    "Repeat" : "Ponovite",
    "Add" : "Dodajte",
    "from" : "od",
    "to" : "do",
    "New calendar" : "Novi kalendar",
    "Primary CalDAV address" : "Primarna CalDAV adresa",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-app-calendar-1.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/hr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Group" : "Grupa",
    "Required" : "Obavezan sudionik",
    "Optional" : "Neobavezan sudionik",
    "Does not attend" : "Ne sudjeluje",
    "{name} ({email})" : "{name} ({email})",
    "New event" : "Novi događaj",
    "CalDAV address for clients" : "Adresa CalDAV za klijente",
    "Share Calendar" : "Zajedničko korištenje Kalendara",
    "Shared" : "Resurs podijeljen",
    "WebDAV address for subscriptions" : "Adresa WebDAV za pretplate",
    "group" : "Grupa",
    "Details" : "Detalji",
    "Attendees" : "Sudionici",
    "Reminders" : "Podsjetnici",
    "Repeating" : "Ponavljanje",
    "Confirmed" : "Potvrđeno",
    "Tentative" : "Probno",
    "Cancelled" : "Otkazano",
    "None" : "Ništa",
    "Every day" : "Svakodnevno",
    "never" : "nikad",
    "after" : "nakon",
    "5 minutes before" : "5 minuta prije",
    "10 minutes before" : "10  minuta prije",
    "15 minutes before" : "15  minuta prije",
    "30 minutes before" : "30  minuta prije",
    "1 hour before" : "1 sat prije",
    "2 hours before" : "2 sata prije",
    "Audio" : "Audio",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min",
    "hours" : "sati",
    "days" : "dana",
    "week" : "tjedan",
    "before" : "prije",
    "Title of the Event" : "Naslov Događaja",
    "Delete" : "Izbrišite",
    "Cancel" : "Odustanite",
    "More ..." : "Više...",
    "Create" : "Kreirajte",
    "Update" : "Ažurirajte",
    "Close" : "Zatvorite",
    "Location" : "Lokacija",
    "Description" : "Opis",
    "Visibility when sharing" : "Vidljivost prilikom dijeljenja",
    "Export" : "Izvoz",
    "Day" : "Dan",
    "Week" : "tjedan",
    "Month" : "Mjesec",
    "Today" : "Danas",
    "More" : "Više",
    "Edit" : "Uređivanje",
    "Link" : "Poveznica",
    "iCal link" : "iCal poveznica",
    "Download" : "Preuzmi",
    "Share with users or groups" : "Podijeli s korisnicima ili grupama",
    "can edit" : "uređivanje moguće",
    "Share link" : "Podijeli vezu",
    "Public access" : "Javni pristup",
    "Email link to person" : "Pošalji poveznicu e-poštom",
    "Send" : "Pošalji",
    "New Calendar" : "Novi kalendar",
    "Name" : "Naziv",
    "New Subscription" : "Nova Pretplata",
    "Go back" : "Nazad",
    "Go forward" : "Dalje",
    "Edit event" : "Uredi događaj",
    "Delete Event" : "Izbriši događaj",
    "Save Event" : "Spremi događaj",
    "Time" : "Vrijeme",
    "Type" : "Vrsta",
    "Repeat" : "Ponovite",
    "Add" : "Dodajte",
    "from" : "od",
    "to" : "do",
    "New calendar" : "Novi kalendar",
    "Primary CalDAV address" : "Primarna CalDAV adresa"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
